[![pipeline status](https://gitlab.com/nicolalandro/streamlit-ketchersa/badges/main/pipeline.svg)](https://gitlab.com/nicolalandro/streamlit-ketchersa/-/commits/main)
[![License: MIT](https://img.shields.io/badge/license-MIT-lightgray)](LICENSE) 

[![Open in Huggingface](https://huggingface.co/datasets/huggingface/badges/raw/refs%2Fpr%2F11/open-in-hf-spaces-md-dark.svg)](https://huggingface.co/spaces/z-uo/DrawMaleculeKetcher)

# Streamlit Ketcher Standalone
This repo is for creating a chemical molecule draw tools for streamlit based on [Ketcher](https://github.com/epam/ketcher/tree/master/packages/ketcher-standalone).

*for now I get html and js from [Online demo](https://lifescience.opensource.epam.com/KetcherDemoSA/index.html) but I need to understand to use the library direactly to have a cleaner solution

|White theme|
|-----------|
|![streamlit app screenshot](imgs/white.png)|

Install from pipy:

```
pip install streamlit_ketchersa
```

Example of usage:

```
import streamlit as st
from streamlit_ketchersa import streamlit_ketchersa

result = streamlit_ketchersa()
st.markdown(result)
```

## Roaadmap

* [x] Start empty project with frontand and python
* [x] Add libary and usage
* [x] interact with streamlit by returning informations
* [x] Setup build.py and pypi readme
* [x] Push on gitlab python registry
* [ ] push on pipy
* [ ] create streamlit demo
* [x] create huggingface demo

## Develop
This is the guide for developers.

### Frontend
```
cd streamlit_ketchersa/frontend
npm install

npm run dev
# http://localhost:5173/
```

### Streamlit
```
python3 -m venv venv
source venv/bin/activate.fish
pip install streamlit

streamlit run streamlit_ketchersa/__init__.py
# http://localhost:8501/
```

## Tesing builded lib
```
python3 -m venv venv
# Set from streamlit_ketchersa/__init__.py _RELEASE=True
pip install -e .
streamlit run test.py
```

## Deploy pipy
```
keyring set https://upload.pypi.org/legacy/ <pypi uname>
```

* prepare your ~/.pypirc file

```
[pypi]
repository=https://upload.pypi.org/legacy/
username = __token__
password = <token>
```

* build frontend

```
cd streamlit_ketchersa/frontend
rm -rf dist
npm run build
```

* build backend

```
pip install twine

# Set from streamlit_ketchersa/__init__.py _RELEASE=True
rm -rf dist

python setup.py sdist
twine check dist/*
```

* upload

```
twine upload dist/*
```

## References
* [python](https://www.python.org/): programming language for develop the tool
* [HTML](https://www.w3schools.com/html/): markup language for the output file generated by the tool
* [JavaScript](https://www.w3schools.com/js/): programming language used into the HTML for logic implementation 
* [vite](https://vitejs.dev/): js builder
* [streamlit](https://streamlit.io/): python library to make quick and dirty UI
* [vite vanilla js streamlit component](https://dev.to/aisone/streamlit-custom-components-vite-vanilla-js-40hl): how to create vanilla js plugin for streamlit
* [Ketcher Standalone](https://github.com/epam/ketcher/tree/master/packages/ketcher-standalone): the ketcher library for draw molecules in standalone mode
* [Ketcher Demo](https://lifescience.opensource.epam.com/ketcher/demo.html): Demo of ketcher
* [How to write setup.py and deploy on pypi](https://medium.com/@joel.barmettler/how-to-upload-your-python-package-to-pypi-65edc5fe9c56): important for deploy the code as python lib
* [Gitlab CI/CD for python registry](https://docs.gitlab.com/ee/user/packages/pypi_repository/): how to setup pipeline to gitlab python registry
